import * as i0 from '@angular/core';
import { InjectionToken, Directive, Component, ChangeDetectionStrategy, Inject, NgZone, HostBinding, ChangeDetectorRef, ViewChild, Input, Injectable, EventEmitter, ElementRef, SecurityContext, Renderer2, Output, ContentChildren, isDevMode, ViewChildren, forwardRef, Injector, ComponentFactoryResolver, ApplicationRef, PLATFORM_ID, ContentChild, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { DOCUMENT, isPlatformBrowser, CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { DomSanitizer, BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { trigger, transition, style, animate, query } from '@angular/animations';
import { Subject, fromEvent, merge, Observable, pipe, from } from 'rxjs';
import { filter, takeUntil, startWith, switchMap, tap, concatMap, map, delay } from 'rxjs/operators';
import { __awaiter } from 'tslib';

const TIP_TAP_EXTENSIONS = new InjectionToken('TIP_TAP_EXTENSIONS');
const extensionLoaderFactory = (promiseExtensionList) => ({
    load: () => promiseExtensionList()
        .then(e => e.default)
        .then(extensionList => extensionList.map(e => e.default))
});

const FadeInAnimation = trigger('fadeIn', [
    transition(':enter', [
        style({ opacity: 0 }),
        animate('150ms cubic-bezier(.13,1.14,1,.92)', style({ opacity: 1 })),
    ]),
    transition(':leave', [
        animate('150ms cubic-bezier(.13,1.14,1,.92)', style({ opacity: 0 }))
    ])
]);

const PopOverPopUpAnimation = trigger('popUp', [
    transition(':enter', [
        query('.popover-wrapper', [
            style({ opacity: 0, transform: 'translate(-50%, -50%)' }),
            animate('150ms cubic-bezier(.13,1.14,1,.92)', style({ opacity: 1, transform: '*' })),
        ])
    ]),
    transition(':leave', query('.popover-wrapper', [
        animate('150ms cubic-bezier(.13,1.14,1,.92)', style({ opacity: 0, transform: 'translate(-50%, -50%)' })),
    ])),
]);
const OverlayPopUpAnimation = trigger('popUp', [
    transition(':enter', [
        query('.dialog-wrapper', [
            style({ transform: 'translate(-50%, -30%)' }),
            animate('150ms cubic-bezier(.13,1.14,1,.92)', style({ transform: '*' })),
        ])
    ]),
    transition(':leave', query('.dialog-wrapper', [
        animate('150ms cubic-bezier(.13,1.14,1,.92)', style({ transform: 'translate(-50%, -30%)' })),
    ])),
]);

const DIALOG_DATA = new InjectionToken('DIALOG_DATA');
class DialogRef {
    /* tslint:enable */
    constructor(_componentInstance, dialogService, dialogComponentRef, config) {
        this._componentInstance = _componentInstance;
        this.dialogService = dialogService;
        this.dialogComponentRef = dialogComponentRef;
        this.config = config;
        /* tslint:disable */
        this.subject$ = new Subject();
        this.result$ = this.subject$.asObservable();
        this.status = 'success';
    }
    get componentInstance() {
        return this._componentInstance;
    }
    get dialogConfig() {
        const copy = Object.assign({}, this.config);
        delete copy.data;
        return copy;
    }
    get dialogComponent() {
        return this.dialogComponentRef.component;
    }
    setStatus(status) {
        this.status = status;
    }
    closeDialog(data) {
        this.dialogService.removeOverlay(this.dialogComponent);
        this.subject$.next({
            data,
            status: this.status
        });
        this.subject$.complete();
    }
}
// tslint:disable-next-line:directive-class-suffix
class DialogBaseClass {
    constructor() {
        this.destroy$ = new Subject();
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            fromEvent(this.document, 'keydown').pipe(filter(e => e.key === 'Escape'), takeUntil(this.destroy$)).subscribe(() => this.ngZone.run(() => this.closeDialog()));
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.complete();
    }
    closeDialog() {
        if (!this.dialogRef.dialogConfig.autoClose)
            return;
        this.dialogRef.setStatus('canceled');
        this.dialogRef.closeDialog(null);
    }
}
DialogBaseClass.decorators = [
    { type: Directive }
];

// @dynamic
class DialogComponent extends DialogBaseClass {
    constructor(data, document, dialogRef, ngZone) {
        super();
        this.data = data;
        this.document = document;
        this.dialogRef = dialogRef;
        this.ngZone = ngZone;
        this.position = {};
        this.position = this.calculateStyle();
    }
    calculateStyle() {
        const config = this.dialogRef.dialogConfig;
        return {
            width: config.width,
            maxWidth: config.maxWidth,
            top: config.position === 'top' ? '20%' : '50%',
        };
    }
}
DialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-dialog',
                template: `
    <div class="overlay" (click)="closeDialog()" [ngStyle]="{backgroundColor: dialogRef.dialogConfig.backdropColor}"></div>
    <div class="dialog-wrapper" [ngStyle]="position">
      <ng-container *ngIf="dialogRef.componentInstance" [ngComponentOutlet]="dialogRef.componentInstance"></ng-container>
    </div>
  `,
                animations: [FadeInAnimation, OverlayPopUpAnimation],
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`
    .overlay {
      position: fixed;
      top: 0;
      bottom: 0;
      right: 0;
      left: 0;
      z-index: 2000;
    }

    .dialog-wrapper {
      left: 50%;
      position: absolute;
      transform: translate(-50%, -50%);
      border-radius: 5px;
      padding: 10px;
      z-index: 2000;
      background-color: var(--tip-background-color);
    }
  `]
            },] }
];
DialogComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DIALOG_DATA,] }] },
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: DialogRef },
    { type: NgZone }
];
DialogComponent.propDecorators = {
    calculateStyle: [{ type: HostBinding, args: ['@fadeIn',] }, { type: HostBinding, args: ['@popUp',] }]
};

// @dynamic
class PopoverComponent extends DialogBaseClass {
    constructor(data, document, dialogRef, ngZone, cd) {
        super();
        this.data = data;
        this.document = document;
        this.dialogRef = dialogRef;
        this.ngZone = ngZone;
        this.cd = cd;
        this.style = {};
        this.style = this.calculateStyle();
    }
    ngAfterViewInit() {
        const position = this.popover.nativeElement.getBoundingClientRect();
        const window = this.document.defaultView;
        if (!window)
            return;
        const windowWidth = window.innerWidth;
        const overflowRight = (position.x + position.width) - windowWidth;
        const updateStyles = {};
        if (position.x < 0) {
            updateStyles.transform = `translate(calc(-50% + ${Math.abs(position.x)}px), -100%)`;
        }
        else if (overflowRight > 0) {
            updateStyles.transform = `translate(calc(-50% - ${overflowRight}px), -100%)`;
        }
        if (Object.keys(updateStyles).length > 0) {
            this.style = Object.assign(Object.assign({}, this.style), updateStyles);
            this.cd.detectChanges();
        }
    }
    calculateStyle() {
        const config = this.dialogRef.dialogConfig;
        return {
            'top.px': config.position.y,
            'left.px': config.position.x,
        };
    }
}
PopoverComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-popover',
                template: `
    <div class="popover-wrapper" [ngStyle]="style" #popover>
      <ng-container *ngIf="dialogRef.componentInstance" [ngComponentOutlet]="dialogRef.componentInstance"></ng-container>
    </div>`,
                animations: [PopOverPopUpAnimation],
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`
    .popover-wrapper {
      border-radius: 5px;
      background-color: var(--tip-background-color);
      position: fixed;
      transform: translate(-50%, -100%);
      border: solid 1px var(--tip-border-color);
      padding: 5px;
      z-index: 2000;
    }`]
            },] }
];
PopoverComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DIALOG_DATA,] }] },
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: DialogRef },
    { type: NgZone },
    { type: ChangeDetectorRef }
];
PopoverComponent.propDecorators = {
    popover: [{ type: ViewChild, args: ['popover',] }],
    ngAfterViewInit: [{ type: HostBinding, args: ['@popUp',] }]
};

class EditorBodyComponent {
    constructor() {
        this.minHeight = '';
        this.maxHeight = '';
        this.editor = null;
        this._editorElement = null;
    }
    get editorElement() {
        return this._editorElement ? this._editorElement.nativeElement : null;
    }
    setEditor(tiptapEditor) {
        this.editor = tiptapEditor;
    }
    get height() {
        if (this.minHeight && !this.maxHeight || this.maxHeight && !this.minHeight) {
            console.warn('You have to set minHeight and maxHeight of the tip-editor-body for it to work properly.\n' +
                'The values however can be the same');
            return '';
        }
        else if (!this.minHeight && !this.maxHeight) {
            return '';
        }
        return '200vh';
    }
}
EditorBodyComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-editor-body, tip-editor-body[minHeight][maxHeight]',
                template: `
    <div class="editor-body" [ngStyle]="{minHeight: minHeight, maxHeight: maxHeight, height: height}">
      <div #editorBody style="height: 100%"></div>
    </div>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".editor-body{border:1px solid var(--tip-border-color);overflow:auto;padding:1rem}::ng-deep .ProseMirror>:first-child{margin-top:0}::ng-deep .ProseMirror>:last-child{margin-bottom:0}"]
            },] }
];
EditorBodyComponent.propDecorators = {
    minHeight: [{ type: Input }],
    maxHeight: [{ type: Input }],
    _editorElement: [{ type: ViewChild, args: ['editorBody', { static: true },] }]
};

class TiptapEventService {
    /* tslint:enable */
    constructor(ngZone) {
        this.ngZone = ngZone;
        this.clickSubject = new Subject();
        this.keyboardSubject = new Subject();
        this.clickSubscription = null;
        this.keyboardSubscription = null;
        /* tslint:disable */
        this.update$ = merge(this.clickSubject, this.keyboardSubject);
        this.onClick$ = this.clickSubject.asObservable();
        this.onKeyboard$ = this.keyboardSubject.asObservable();
    }
    registerShortcut(shortcut) {
        const parts = shortcut.split('-');
        let key = parts[parts.length - 1];
        if (key === 'Space')
            key = ' ';
        const keyCodeSmall = key.toUpperCase().charCodeAt(0);
        const keyCodeLarge = key.toLowerCase().charCodeAt(0);
        const hasAlt = parts.includes('Alt');
        const hasShift = parts.includes('Shift');
        const hasMod = parts.includes('Mod');
        const hasCtrl = parts.includes('Ctrl');
        const hasCmd = parts.includes('Cmd');
        return this.onKeyboard$.pipe(filter(e => (
        // Check the keycode against the large and small letter (I hate you apple)
        (e.keyCode === keyCodeSmall || e.keyCode === keyCodeLarge) &&
            e.altKey === hasAlt &&
            e.shiftKey === hasShift &&
            // Check if the meta key was pressed, or the combined mod is allowed  (I really, really, hate you apple)
            (
            // Both ctrl and command key
            hasMod && (e.ctrlKey && !e.metaKey || !e.ctrlKey && e.metaKey)
                // Only ctrl or command key
                || e.ctrlKey === hasCtrl && e.metaKey === hasCmd && !hasMod))));
    }
    setElement(element) {
        this.ngZone.runOutsideAngular(() => {
            var _a, _b;
            (_a = this.clickSubscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
            (_b = this.keyboardSubscription) === null || _b === void 0 ? void 0 : _b.unsubscribe();
            this.clickSubscription = fromEvent(element, 'click').subscribe(e => this.clickSubject.next(e));
            this.keyboardSubscription = fromEvent(element, 'keydown').subscribe(e => this.keyboardSubject.next(e));
        });
    }
}
TiptapEventService.ɵprov = i0.ɵɵdefineInjectable({ factory: function TiptapEventService_Factory() { return new TiptapEventService(i0.ɵɵinject(i0.NgZone)); }, token: TiptapEventService, providedIn: "root" });
TiptapEventService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
TiptapEventService.ctorParameters = () => [
    { type: NgZone }
];

const ExpandHeight = trigger('expandHeight', [
    transition(':enter', [
        style({ height: '0' }),
        animate('100ms cubic-bezier(.13,1.14,1,.92)', style({ height: '*' })),
    ]),
    transition(':leave', animate('100ms cubic-bezier(.13,1.14,1,.92)', style({ height: '0' })))
]);

class OptionComponent {
    constructor(element) {
        this.element = element;
        this.onSelect = new EventEmitter();
        this.enforceHeight = false;
        this.useHtml = false;
        this._disabled = false;
    }
    set disabled(value) {
        if (this.option && value) {
            this.option.nativeElement.setAttribute('disabled', 'true');
        }
        else {
            this.option && this.option.nativeElement.removeAttribute('disabled');
        }
        this._disabled = false;
    }
    setSelected(value) {
        this.addOrRemoveClass(value, 'active');
    }
    emit($event) {
        $event.preventDefault();
        this.onSelect.emit(this);
    }
    getContent() {
        return this.useHtml ? this.element.nativeElement.innerHTML : this.element.nativeElement.textContent;
    }
    addOrRemoveClass(add, className) {
        const operation = add ? 'add' : 'remove';
        this.option && this.option.nativeElement.classList[operation](className);
    }
}
OptionComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-option[value]',
                template: `
    <button (click)="emit($event)" (keydown.enter)="emit($event)"
            class="select-option select-overflow-wrapper" #option>
      <ng-content></ng-content>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [":host-context(tip-select){display:flex}.select-wrapper{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;outline-offset:-1}.select-preview,.select-wrapper{display:inline-flex;align-items:center}.select-preview{overflow:hidden;box-sizing:border-box;width:100%;height:var(--tip-select-preview-height);padding:0 .2rem;cursor:pointer;border:1px solid var(--tip-border-color)}.select-preview:focus{color:var(--tip-active-color)}.select-preview.icon-placeholder{padding-right:var(--tip-select-preview-height)}.select-overflow-wrapper{overflow:hidden;box-sizing:border-box;width:100%;white-space:nowrap;display:flex;align-items:center;text-overflow:ellipsis}.select-options-overlay{position:absolute;z-index:1;top:0;width:100%;cursor:pointer;transform:translateY(var(--tip-select-preview-height));background-color:var(--tip-background-color);overflow-y:hidden}.select-icon{position:absolute;top:50%;right:0;height:var(--tip-select-preview-height);transform:translateY(-50%);transition:rotate .3s;fill:var(--tip-text-color)}.select-icon.rotate180{transform:rotate(180deg) translateY(50%)}::ng-deep tip-select .select-preview-content,::ng-deep tip-select .select-preview-content>.select-option{height:var(--tip-select-preview-height)}.select-option{padding:.2rem;transition:color .3s;border:1px solid var(--tip-border-color);border-top:none;background-color:transparent;color:var(--tip-text-color)}.select-option[disabled]{color:var(--tip-border-color)}.select-option:not([disabled]){cursor:pointer}.select-option:not([disabled]).tip-active,.select-option:not([disabled]):focus,.select-option:not([disabled]):hover{color:var(--tip-active-color)}"]
            },] }
];
OptionComponent.ctorParameters = () => [
    { type: ElementRef }
];
OptionComponent.propDecorators = {
    disabled: [{ type: Input }],
    value: [{ type: Input }],
    enforceHeight: [{ type: Input }],
    useHtml: [{ type: Input }],
    option: [{ type: ViewChild, args: ['option',] }]
};
// @dynamic
class SelectComponent {
    constructor(cd, element, ngZone, renderer2, sanitizer, document) {
        this.cd = cd;
        this.element = element;
        this.ngZone = ngZone;
        this.renderer2 = renderer2;
        this.sanitizer = sanitizer;
        this.document = document;
        this.width = '150px';
        this.placeholder = '';
        this.defaultValue = '';
        this.showIcon = true;
        // tslint:disable-next-line:no-output-native
        this.change = new EventEmitter();
        // Is the dropdown visible
        this.visible = false;
        this.destroy$ = new Subject();
    }
    get value() {
        return this._value;
    }
    set value(value) {
        // Nothing changed
        if (value === this._value)
            return;
        this._value = value;
        this.updateComponent(false);
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            fromEvent(this.document, 'keyup').pipe(filter(e => e.key === 'Escape'), filter(() => this.visible), takeUntil(this.destroy$)).subscribe(() => {
                this.ngZone.run(() => {
                    this.visible = false;
                    this.cd.markForCheck();
                });
            });
            fromEvent(this.document, 'click').pipe(filter(e => !this.element.nativeElement.contains(e.target) && this.visible), takeUntil(this.destroy$)).subscribe((e) => {
                console.log(this.element.nativeElement, this.element.nativeElement.contains(e.target));
                this.ngZone.run(() => {
                    this.visible = false;
                    this.cd.markForCheck();
                });
            });
        });
    }
    ngAfterViewInit() {
        // Subscribe to click events on the options
        const options = this.optionList;
        this.optionList.changes.pipe(startWith(...options), switchMap(() => merge(...options.map(o => o.onSelect))), takeUntil(this.destroy$)).subscribe(component => {
            // Nothing changed
            if (this._value === component.value)
                return;
            this._value = component.value;
            this.visible = false;
            this.updateComponent(true);
        });
        // Update the selected value for the initial select
        this.updateComponent(false);
    }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    toggle($event) {
        $event.stopPropagation();
        this.visible = !this.visible;
    }
    /**
     * Select the current component depending on the selected value
     * @param emitUpdate Should the change be propagated
     */
    updateComponent(emitUpdate) {
        var _a;
        // No options => no update
        if (!this.optionList)
            return;
        // If no value is provided use the default value
        if (!this.value && this.defaultValue) {
            this._value = this.defaultValue;
        }
        // Deselect all
        this.optionList.forEach(o => o.setSelected(false));
        // Select right one
        const selectedComponent = this.optionList.find(o => o.value === this._value);
        let previewText = this.placeholder;
        // A component is selected, so select the component
        if (selectedComponent) {
            selectedComponent.setSelected(true);
            previewText = selectedComponent.getContent();
            emitUpdate && this.change.emit(selectedComponent.value);
        }
        const sanitizedHtml = this.sanitizer.sanitize(SecurityContext.HTML, previewText);
        this.selectPreview && this.renderer2.setProperty((_a = this.selectPreview) === null || _a === void 0 ? void 0 : _a.nativeElement, 'innerHTML', sanitizedHtml);
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-select',
                template: "<div [ngStyle]=\"{width: width}\" class=\"select-wrapper\">\n  <div (click)=\"toggle($event)\" (keydown.enter)=\"toggle($event)\" [class.icon-placeholder]=\"showIcon\"\n       class=\"select-preview\"\n       tabindex=\"0\">\n    <div #selectPreview\n         class=\"select-overflow-wrapper select-preview-content\">\n    </div>\n    <i *ngIf=\"showIcon\" [class.rotate180]=\"visible\" class=\"select-icon\">\n      <svg focusable=\"false\" height=\"24px\" viewBox=\"0 0 24 24\" width=\"24px\">\n        <path d=\"M7 10l5 5 5-5z\"/>\n      </svg>\n    </i>\n  </div>\n  <div *ngIf=\"visible\" class=\"select-options-overlay\" @expandHeight>\n    <ng-content></ng-content>\n  </div>\n</div>\n\n",
                animations: [FadeInAnimation, ExpandHeight],
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [":host-context(tip-select){display:flex}.select-wrapper{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;outline-offset:-1}.select-preview,.select-wrapper{display:inline-flex;align-items:center}.select-preview{overflow:hidden;box-sizing:border-box;width:100%;height:var(--tip-select-preview-height);padding:0 .2rem;cursor:pointer;border:1px solid var(--tip-border-color)}.select-preview:focus{color:var(--tip-active-color)}.select-preview.icon-placeholder{padding-right:var(--tip-select-preview-height)}.select-overflow-wrapper{overflow:hidden;box-sizing:border-box;width:100%;white-space:nowrap;display:flex;align-items:center;text-overflow:ellipsis}.select-options-overlay{position:absolute;z-index:1;top:0;width:100%;cursor:pointer;transform:translateY(var(--tip-select-preview-height));background-color:var(--tip-background-color);overflow-y:hidden}.select-icon{position:absolute;top:50%;right:0;height:var(--tip-select-preview-height);transform:translateY(-50%);transition:rotate .3s;fill:var(--tip-text-color)}.select-icon.rotate180{transform:rotate(180deg) translateY(50%)}::ng-deep tip-select .select-preview-content,::ng-deep tip-select .select-preview-content>.select-option{height:var(--tip-select-preview-height)}.select-option{padding:.2rem;transition:color .3s;border:1px solid var(--tip-border-color);border-top:none;background-color:transparent;color:var(--tip-text-color)}.select-option[disabled]{color:var(--tip-border-color)}.select-option:not([disabled]){cursor:pointer}.select-option:not([disabled]).tip-active,.select-option:not([disabled]):focus,.select-option:not([disabled]):hover{color:var(--tip-active-color)}"]
            },] }
];
SelectComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone },
    { type: Renderer2 },
    { type: DomSanitizer },
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
SelectComponent.propDecorators = {
    value: [{ type: Input }],
    width: [{ type: Input }],
    placeholder: [{ type: Input }],
    defaultValue: [{ type: Input }],
    showIcon: [{ type: Input }],
    change: [{ type: Output }],
    optionList: [{ type: ContentChildren, args: [OptionComponent, { descendants: true },] }],
    selectPreview: [{ type: ViewChild, args: ['selectPreview',] }]
};

class BaseControl {
    constructor() {
        this._editor = null;
    }
    get editor() {
        return this._editor;
    }
    setEditor(editor) {
        this._editor = editor;
        this.onEditorReady && this.onEditorReady(editor);
    }
}
// tslint:disable-next-line:directive-class-suffix
class ExtendedBaseControl extends BaseControl {
    constructor() {
        super(...arguments);
        this.destroy$ = new Subject();
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.complete();
    }
    isEditable() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isEditable);
    }
}
ExtendedBaseControl.decorators = [
    { type: Directive }
];
// tslint:disable-next-line:directive-class-suffix
class ButtonBaseControl extends ExtendedBaseControl {
    ngOnInit() {
        this.eventService.update$
            .pipe(takeUntil(this.destroy$))
            .subscribe(() => this.updateButton());
    }
    ngAfterViewInit() {
        if (!this.button && isDevMode()) {
            console.warn(`The button element in your control could not be found in ${this.constructor.name}\nPlease add #button to your control button element`);
        }
    }
    setEditor(editor) {
        super.setEditor(editor);
        this.updateButton();
    }
    updateButton() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.button)
                return;
            const activeAction = (yield this.isActive()) ? 'add' : 'remove';
            this.button.nativeElement.classList[activeAction]('tip-active');
            if ((yield this.can()) && this.isEditable()) {
                this.button.nativeElement.removeAttribute('disabled');
            }
            else {
                this.button.nativeElement.setAttribute('disabled', 'true');
            }
        });
    }
}
ButtonBaseControl.decorators = [
    { type: Directive }
];
ButtonBaseControl.propDecorators = {
    button: [{ type: ViewChild, args: ['button',] }]
};
// tslint:disable-next-line:directive-class-suffix
class SelectBaseControl extends ExtendedBaseControl {
    constructor() {
        super(...arguments);
        this.canStyleParams = [];
    }
    ngOnInit() {
        this.eventService.update$.pipe(takeUntil(this.destroy$)).subscribe(() => {
            this.updateSelectValue();
            this.updateDisabledValue();
        });
    }
    ngAfterViewInit() {
        if (!isDevMode() && !this.select) {
            console.warn(`The select element in your control could not be found in ${this.constructor.name}\nPlease make sure you have a tip-select in your component`);
        }
    }
    setEditor(editor) {
        super.setEditor(editor);
        this.updateSelectValue();
        this.updateDisabledValue();
    }
    updateSelectValue() {
        return __awaiter(this, void 0, void 0, function* () {
            this.select.value = yield this.currentActive();
        });
    }
    updateDisabledValue() {
        return __awaiter(this, void 0, void 0, function* () {
            const optionsList = this.options.toArray();
            for (const [index, param] of this.canStyleParams.entries()) {
                const option = optionsList[index];
                if (!option)
                    continue;
                option.disabled = !((yield this.canStyle(param)) && this.isEditable());
            }
        });
    }
}
SelectBaseControl.decorators = [
    { type: Directive }
];
SelectBaseControl.propDecorators = {
    select: [{ type: ViewChild, args: [SelectComponent,] }],
    options: [{ type: ViewChildren, args: [OptionComponent,] }]
};

class BoldControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleBold() {
        this.editor && this.editor.chain().focus().toggleBold().run();
    }
    isActive() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('bold'));
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleBold());
    }
}
BoldControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-bold-control',
                template: `
    <button (click)="toggleBold()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">format_bold</i>
    </button>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => BoldControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
BoldControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class BulletListControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleList() {
        this.editor && this.editor.chain().focus().toggleBulletList().run();
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleBulletList());
    }
    isActive(...args) {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('bulletList'));
    }
}
BulletListControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-bullet-list-control',
                template: `
    <button (click)="toggleList()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">format_list_bulleted</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => BulletListControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
BulletListControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class CodeBlockControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleCodeBlock() {
        this.editor && this.editor.chain().focus().toggleCodeBlock().run();
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleCodeBlock());
    }
    isActive(...args) {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('codeBlock'));
    }
}
CodeBlockControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-code-block-control',
                template: `
    <button (click)="toggleCodeBlock()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">integration_instructions</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => CodeBlockControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
CodeBlockControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class CodeControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleCode() {
        this.editor && this.editor.chain().focus().toggleCode().run();
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleCode());
    }
    isActive(...args) {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('code'));
    }
}
CodeControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-code-control',
                template: `
    <button (click)="toggleCode()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">code</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => CodeControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
CodeControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

const findExtension = (editor, name) => {
    return editor.extensionManager.extensions.find(e => e.name === name);
};
const ɵ0$1 = findExtension;
const getHeadingsExtension = (editor) => {
    return findExtension(editor, 'heading');
};
const newUIntArrives = source => {
    let last = -1;
    return source.pipe(filter(num => num !== last), tap(num => last = num));
};
const sleep = (ms) => new Promise(resolve => setTimeout(resolve, ms));
const fromEditorEvent = (editor, event) => {
    return new Observable((observer) => {
        const callback = (...params) => {
            observer.next(...params);
        };
        editor.on(event, callback);
        return () => {
            editor.off(event, callback);
        };
    });
};
function asyncFilter(predicate) {
    let count = 0;
    return pipe(
    // Convert the predicate Promise<boolean> to an observable (which resolves the promise,
    // Then combine the boolean result of the promise with the input data to a container object
    concatMap((data) => {
        return from(predicate(data, count++))
            .pipe(map((isValid) => ({ filterResult: isValid, entry: data })));
    }), 
    // Filter the container object synchronously for the value in each data container object
    filter(data => data.filterResult), 
    // remove the data container object from the observable chain
    map(data => data.entry));
}

const isHeading = (level) => typeof level === 'number';
const ɵ0 = isHeading;
class FormatControlComponent extends SelectBaseControl {
    constructor(eventService, cd) {
        super();
        this.eventService = eventService;
        this.cd = cd;
        this.levels = [];
        this.headingHtml = {};
        this.canStyleParams = [];
    }
    setEditor(editor) {
        super.setEditor(editor);
        this.levels = getHeadingsExtension(editor).options.levels;
        this.canStyleParams = [...this.levels, 'paragraph'];
        this.headingHtml = [...this.levels].reduce((previousValue, currentValue) => {
            previousValue[currentValue] = `<h${currentValue} class="no-margin light-font">Heading ${currentValue}</h${currentValue}>`;
            return previousValue;
        }, {});
        this.cd.detectChanges();
    }
    selectTextLevel(format) {
        if (isHeading(format)) {
            this.setHeading(format);
        }
        else {
            this.setParagraph();
        }
    }
    canStyle(format) {
        if (!this.editor)
            return false;
        if (isHeading(format)) {
            return this.editor.can().chain().setHeading({ level: format }).run();
        }
        else {
            return this.editor.can().chain().setParagraph().run();
        }
    }
    currentActive() {
        if (this.editor) {
            const headingAttributes = this.editor.getAttributes('heading');
            if (headingAttributes.level)
                return headingAttributes.level;
            if (this.editor.isActive('paragraph'))
                return 'paragraph';
        }
        return null;
    }
    setParagraph() {
        this.editor && this.editor.chain().setParagraph().run();
    }
    setHeading(headingLevel) {
        this.editor && this.editor.chain().focus().setHeading({ level: headingLevel }).focus().run();
    }
}
FormatControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-format-control',
                template: `
    <tip-select (change)="selectTextLevel($event)" defaultValue="paragraph">
      <tip-option *ngFor="let level of levels" [value]="level">
        <div [innerHTML]="headingHtml[level]"></div>
      </tip-option>
      <tip-option value="paragraph">Paragraph</tip-option>
    </tip-select>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => FormatControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
FormatControlComponent.ctorParameters = () => [
    { type: TiptapEventService },
    { type: ChangeDetectorRef }
];

class HorizontalRuleControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    addHorizontalRule() {
        this.editor && this.editor.chain().focus().setHorizontalRule().run();
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().setHorizontalRule());
    }
    isActive(...args) {
        return false;
    }
}
HorizontalRuleControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-hr-control',
                template: `
    <button (click)="addHorizontalRule()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">horizontal_rule</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => HorizontalRuleControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
HorizontalRuleControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class ItalicControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleItalic() {
        this.editor && this.editor.chain().focus().toggleItalic().run();
    }
    isActive() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('italic'));
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleItalic());
    }
}
ItalicControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-italic-control',
                template: `
    <button (click)="toggleItalic()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">format_italic</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => ItalicControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
ItalicControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

// @dynamic
class DialogService {
    constructor(componentFactoryResolver, appRef, injector, document) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.appRef = appRef;
        this.injector = injector;
        this.document = document;
    }
    openDialog(component, config = {}) {
        // Fill with default values
        const newConfig = Object.assign({
            type: 'dialog',
            autoClose: true,
            maxWidth: '1000px',
            width: '50%',
            backdropColor: 'var(--tip-overlay-color)',
            position: 'center'
        }, config);
        return this.createAndAttachComponent(component, newConfig, DialogComponent);
    }
    openPopover(component, config) {
        const newConfig = Object.assign({
            type: 'popover',
            autoClose: true,
            maxWidth: 'auto',
            width: 'auto',
            backdropColor: 'transparent',
        }, config);
        return this.createAndAttachComponent(component, newConfig, PopoverComponent);
    }
    removeOverlay(componentRef) {
        this.appRef.detachView(componentRef.hostView);
        componentRef.destroy();
    }
    createAndAttachComponent(component, config, wrapperComponent) {
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(wrapperComponent);
        const dialogReference = {};
        const dialogRef = new DialogRef(component, this, dialogReference, config);
        const componentInjector = Injector.create({
            providers: [
                { provide: DIALOG_DATA, useValue: config.data },
                { provide: DialogRef, useValue: dialogRef }
            ],
            parent: this.injector
        });
        const componentRef = componentFactory.create(componentInjector);
        dialogReference.component = componentRef;
        this.appRef.attachView(componentRef.hostView);
        const domElement = componentRef.hostView.rootNodes[0];
        this.document.body.appendChild(domElement);
        return dialogRef;
    }
}
DialogService.ɵprov = i0.ɵɵdefineInjectable({ factory: function DialogService_Factory() { return new DialogService(i0.ɵɵinject(i0.ComponentFactoryResolver), i0.ɵɵinject(i0.ApplicationRef), i0.ɵɵinject(i0.INJECTOR), i0.ɵɵinject(i1.DOCUMENT)); }, token: DialogService, providedIn: "root" });
DialogService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
DialogService.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];

class LinkPreviewComponent {
    constructor(dialogRef, link) {
        this.dialogRef = dialogRef;
        this.link = link;
    }
    deleteLink() {
        this.dialogRef.closeDialog('delete');
    }
}
LinkPreviewComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-link-preview',
                template: `
    <div class="flex">
      <a class="v-center link-text" target="_blank" [href]="link">
        {{link}}
      </a>
      <i class="material-icons pointer" (click)="deleteLink()">delete</i>
    </div>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
LinkPreviewComponent.ctorParameters = () => [
    { type: DialogRef },
    { type: String, decorators: [{ type: Inject, args: [DIALOG_DATA,] }] }
];

// @dynamic
class LinkSelectComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.error = null;
        this.urlRegex = new RegExp('^(https?:\\/\\/)?' + // protocol
            '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|' + // domain name
            '((\\d{1,3}\\.){3}\\d{1,3}))' + // OR ip (v4) address
            '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*' + // port and path
            '(\\?[;&a-z\\d%_.~+=-]*)?' + // query string
            '(\\#[-a-z\\d_]*)?$', 'i');
    }
    submit(value, event) {
        // Stop selected text being replaced by the enter
        event && event.preventDefault();
        if (!/^(https?:\/\/).*/.test(value))
            value = `https://${value}`;
        if (this.urlRegex.test(value)) {
            this.dialogRef.closeDialog(value);
        }
        else {
            this.error = 'Invalid URL';
        }
    }
}
LinkSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-link-select',
                template: `
    <h4 class="no-margin light-font small-padding-bottom">{{data?.popupText}}</h4>
    <input class="tip-input" [placeholder]="data?.inputPlaceholder" tipAutofocus type="text" #input
           (keydown.enter)="submit(input.value, $event)">
    <br>
    <small style="color: var(--tip-warn-color)" *ngIf="error">{{error}}</small>
    <div class="align-right small-padding-top">
      <button class="tip-button" (click)="submit(input.value)">Submit</button>
    </div>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
LinkSelectComponent.ctorParameters = () => [
    { type: DialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [DIALOG_DATA,] }] }
];

// @dynamic
class LinkControlComponent extends ButtonBaseControl {
    constructor(dialogService, eventService, ngZone, document) {
        super();
        this.dialogService = dialogService;
        this.eventService = eventService;
        this.ngZone = ngZone;
        this.document = document;
        this.popupText = 'Input your link';
        this.inputPlaceholder = 'Input link';
        this.tooltipRef = null;
    }
    onEditorReady(editor) {
        this.eventService.registerShortcut('Mod-k')
            .pipe(tap((e) => e.preventDefault()), asyncFilter(() => this.can()), takeUntil(this.destroy$))
            .subscribe((e) => {
            e.preventDefault();
            this.openLinkDialog();
        });
        fromEditorEvent(editor, 'transaction').pipe(takeUntil(this.destroy$)).subscribe(({ editor: e }) => this.openLinkPreview(e));
        fromEditorEvent(editor, 'blur').pipe(filter(() => !!this.tooltipRef), delay(500), takeUntil(this.destroy$)).subscribe(() => this.closeLinkPreview());
    }
    openLinkDialog() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.editor)
                return;
            const link = this.editor.getAttributes('link');
            const data = link.href ? link.href : null;
            const ref = this.ngZone.run(() => this.dialogService.openDialog(LinkSelectComponent, {
                width: 'auto', data: {
                    link: data,
                    popupText: this.popupText,
                    inputPlaceholder: this.inputPlaceholder
                }
            }));
            const result = yield ref.result$.toPromise();
            if (result.status === 'canceled')
                return;
            this.editor.chain().focus().setLink({ href: result.data }).run();
        });
    }
    can() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            yield sleep(0);
            if (!this.editor)
                return false;
            const selection = this.editor.state.selection;
            if (selection.from === selection.to)
                return false;
            return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().setLink({ href: '' })) && !this.isActive();
        });
    }
    isActive() {
        return !!this.editor && 'href' in this.editor.getAttributes('link');
    }
    openLinkPreview(editor) {
        return __awaiter(this, void 0, void 0, function* () {
            if (
            // Not active
            !this.isActive() ||
                // Text selection
                editor.view.state.selection.from !== editor.view.state.selection.to) {
                return this.closeLinkPreview();
            }
            // Already open
            if (this.tooltipRef)
                return;
            // Get the link and the style of the anchor element
            const link = editor.getAttributes('link').href;
            const linkElement = this.getLinkElement(link);
            if (!linkElement)
                return this.closeLinkPreview();
            const position = linkElement.getBoundingClientRect();
            this.tooltipRef = this.ngZone.run(() => this.dialogService.openPopover(LinkPreviewComponent, {
                position: {
                    x: position.x + position.width / 2,
                    y: position.y
                },
                data: link
            }));
            const result = yield this.tooltipRef.result$.toPromise();
            if (result.data === 'delete' && this.editor)
                this.editor.chain().focus().unsetLink().run();
            this.closeLinkPreview();
        });
    }
    getLinkElement(link) {
        let linkSelector = 'a';
        if (link)
            linkSelector = `a[href="${link}"]`;
        // Get current selection
        const selection = this.document.getSelection();
        // Check if the link element can be found
        if (!selection || !selection.anchorNode || !selection.anchorNode.parentElement)
            return null;
        // Get the link element and query for it if the parent node is not a link
        const startElement = selection.anchorNode.parentElement;
        let newLinkElement = startElement;
        if (newLinkElement.tagName !== 'A')
            newLinkElement = startElement.querySelector(linkSelector);
        if (!newLinkElement)
            newLinkElement = startElement.closest(linkSelector);
        if (!newLinkElement)
            return null;
        return newLinkElement;
    }
    closeLinkPreview() {
        if (this.tooltipRef) {
            this.ngZone.run(() => {
                this.tooltipRef.closeDialog(null);
                this.tooltipRef = null;
            });
        }
    }
}
LinkControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-link-control',
                template: `
    <button (click)="openLinkDialog()" disabled #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">link</i>
    </button>`,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => LinkControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
LinkControlComponent.ctorParameters = () => [
    { type: DialogService },
    { type: TiptapEventService },
    { type: NgZone },
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
LinkControlComponent.propDecorators = {
    popupText: [{ type: Input }],
    inputPlaceholder: [{ type: Input }]
};

class NumberListControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleList() {
        this.editor && this.editor.chain().focus().toggleOrderedList().run();
    }
    can(...args) {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleOrderedList());
    }
    isActive(...args) {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('orderedList'));
    }
}
NumberListControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-number-list-control',
                template: `
    <button (click)="toggleList()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">format_list_numbered</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => NumberListControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
NumberListControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class StrikeControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleList() {
        this.editor && this.editor.chain().focus().toggleStrike().run();
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleStrike());
    }
    isActive(...args) {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('strike'));
    }
}
StrikeControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-strike-control',
                template: `
    <button (click)="toggleList()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">format_strikethrough</i>
    </button>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => StrikeControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
StrikeControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class TextAlignControlComponent extends SelectBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
        this.canStyleParams = ['left', 'right', 'center', 'justify'];
    }
    setAlign(alignment) {
        this.editor && this.editor.chain().focus().setTextAlign(alignment).run();
    }
    canStyle(alignment) {
        if (!this.editor)
            return false;
        return this.editor.can().setTextAlign(alignment);
    }
    currentActive() {
        if (this.editor) {
            if (this.editor.isActive({ textAlign: 'left' }))
                return 'left';
            if (this.editor.isActive({ textAlign: 'right' }))
                return 'right';
            if (this.editor.isActive({ textAlign: 'center' }))
                return 'center';
            if (this.editor.isActive({ textAlign: 'justify' }))
                return 'justify';
        }
        return null;
    }
}
TextAlignControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-text-align-control',
                template: `
    <tip-select defaultValue="left" width="auto" [showIcon]="false"
                (change)="setAlign($event)">
      <tip-option value="left" [useHtml]="true" [enforceHeight]="true">
        <i class="material-icons">format_align_left</i>
      </tip-option>
      <tip-option value="right" [useHtml]="true" [enforceHeight]="true">
        <i class="material-icons">format_align_right</i>
      </tip-option>
      <tip-option value="center" [useHtml]="true" [enforceHeight]="true">
        <i class="material-icons">format_align_center</i>
      </tip-option>
      <tip-option value="justify" [useHtml]="true" [enforceHeight]="true">
        <i class="material-icons">format_align_justify</i>
      </tip-option>
    </tip-select>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => TextAlignControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
TextAlignControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class UnderlineControlComponent extends ButtonBaseControl {
    constructor(eventService) {
        super();
        this.eventService = eventService;
    }
    toggleUnderline() {
        this.editor && this.editor.chain().focus().toggleUnderline().run();
    }
    can() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.can().toggleUnderline());
    }
    isActive() {
        var _a;
        return !!((_a = this.editor) === null || _a === void 0 ? void 0 : _a.isActive('underline'));
    }
}
UnderlineControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-underline-control',
                template: `
    <button (click)="toggleUnderline()" #button>
      <div class="content-wrapper" #ref>
        <ng-content #ref></ng-content>
      </div>
      <i *ngIf="ref.childNodes.length === 0" class="material-icons">format_underline</i>
    </button>
  `,
                providers: [{ provide: BaseControl, useExisting: forwardRef(() => UnderlineControlComponent) }],
                styles: [":host-context{display:contents}.tip-active{color:var(--tip-active-color)}button{display:inline-flex;align-items:center;justify-content:center;cursor:pointer;border:none;background-color:var(--tip-background-color);color:var(--tip-text-color)}button:focus,button:hover{color:var(--tip-active-color)}button[disabled]{color:var(--tip-disabled-color);cursor:default}.content-wrapper{display:contents}"]
            },] }
];
UnderlineControlComponent.ctorParameters = () => [
    { type: TiptapEventService }
];

class EditorHeaderComponent {
    constructor() {
        this.editor = null;
        this.children = null;
    }
    setEditor(tiptapEditor) {
        this.editor = tiptapEditor;
        this.passEditorToControls();
    }
    passEditorToControls() {
        this.children && this.children.forEach(control => this.editor && control.setEditor(this.editor));
    }
}
EditorHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-editor-header',
                template: `
    <div class="controls-row">
      <ng-content></ng-content>
    </div>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".controls-row{display:flex;align-items:center;flex-wrap:wrap;box-sizing:border-box;min-height:var(--tip-header-height);padding:var(--tip-header-padding);border:1px solid var(--tip-border-color);border-bottom:none}"]
            },] }
];
EditorHeaderComponent.propDecorators = {
    children: [{ type: ContentChildren, args: [BaseControl,] }]
};

class ControlBreakLineComponent {
}
ControlBreakLineComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-control-break-line',
                template: ``,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`:host-context {
    flex-basis: 100%;
  }`]
            },] }
];

class ControlHorizontalDividerComponent {
}
ControlHorizontalDividerComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-control-horizontal-divider',
                template: `
    <hr>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`
    :host-context {
      display: contents;
    }

    hr {
      flex-basis: calc(100% + var(--tip-header-padding) * 2);
      margin: var(--tip-header-padding) calc(var(--tip-header-padding) * -1);
      border: none;
      border-top: solid 1px var(--tip-border-color);
    }`]
            },] }
];

class ControlSpacerComponent {
}
ControlSpacerComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-control-spacer',
                template: ``,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`:host-context {
    flex-grow: 1;
  }`]
            },] }
];

class ControlVerticalDividerComponent {
}
ControlVerticalDividerComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-control-vertical-divider',
                template: ``,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`:host-context {
    width: 1px;
    border-left: solid 1px var(--tip-border-color);
    height: var(--tip-header-height);
    margin-top: calc(var(--tip-header-padding) * -1);
    margin-bottom: calc(var(--tip-header-padding) * -1);
  }`]
            },] }
];

const loadCore = () => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        tiptapCore: yield import('@tiptap/core'),
    });
});

class TiptapService {
    constructor(ngZone, extensionLoader) {
        this.ngZone = ngZone;
        this.extensionLoader = extensionLoader;
        this.tiptapCore = null;
        this.extensionPromise = null;
    }
    getEditor(editorElement, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const tipTapModule = yield this.getTipTap();
            return this.ngZone.runOutsideAngular(() => __awaiter(this, void 0, void 0, function* () {
                return new tipTapModule.Editor(Object.assign(Object.assign({}, options), { element: editorElement, extensions: yield this.getExtensions() }));
            }));
        });
    }
    getExtensions() {
        if (!this.extensionPromise) {
            this.extensionPromise = this.extensionLoader.load();
        }
        return this.extensionPromise;
    }
    getTipTap() {
        return this.loadTiptapCore().then((CORE) => CORE.tiptapCore);
    }
    loadTiptapCore() {
        if (!this.tiptapCore) {
            this.tiptapCore = loadCore();
        }
        return this.tiptapCore;
    }
}
TiptapService.ɵprov = i0.ɵɵdefineInjectable({ factory: function TiptapService_Factory() { return new TiptapService(i0.ɵɵinject(i0.NgZone), i0.ɵɵinject(TIP_TAP_EXTENSIONS)); }, token: TiptapService, providedIn: "root" });
TiptapService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
TiptapService.ctorParameters = () => [
    { type: NgZone },
    { type: undefined, decorators: [{ type: Inject, args: [TIP_TAP_EXTENSIONS,] }] }
];

class EditorPreviewComponent {
    constructor(tiptapService, domSanitizer, renderer) {
        this.tiptapService = tiptapService;
        this.domSanitizer = domSanitizer;
        this.renderer = renderer;
        this.sanitizeHtml = true;
        this._content = null;
    }
    set content(value) {
        this._content = value;
        this.renderOutput().then();
    }
    ngOnInit() {
        return __awaiter(this, void 0, void 0, function* () {
            this.tipTap = yield this.tiptapService.getTipTap();
        });
    }
    ngAfterViewInit() {
        return this.renderOutput();
    }
    renderOutput(content = this._content) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.contentOutlet)
                return;
            let html = '';
            if (typeof content === 'string') {
                html = content;
            }
            else if (content) {
                html = this.tipTap.generateHTML(content, yield this.tiptapService.getExtensions());
            }
            if (this.sanitizeHtml) {
                html = this.domSanitizer.sanitize(SecurityContext.HTML, html);
            }
            this.renderer.setProperty(this.contentOutlet.nativeElement, 'innerHTML', html);
        });
    }
}
EditorPreviewComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-editor-preview',
                template: `
    <div #contentOutlet></div>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];
EditorPreviewComponent.ctorParameters = () => [
    { type: TiptapService },
    { type: DomSanitizer },
    { type: Renderer2 }
];
EditorPreviewComponent.propDecorators = {
    content: [{ type: Input }],
    contentOutlet: [{ type: ViewChild, args: ['contentOutlet',] }],
    sanitizeHtml: [{ type: Input }]
};

// tslint:disable:no-output-native
class EditorComponent {
    constructor(tiptapService, ngZone, element, platformId, dialogService, eventService) {
        this.tiptapService = tiptapService;
        this.ngZone = ngZone;
        this.element = element;
        this.platformId = platformId;
        // Content change
        this.jsonChange = new EventEmitter();
        this.htmlChange = new EventEmitter();
        // Editor set
        this.created = new EventEmitter();
        // Editor events
        this.beforeCreate = new EventEmitter();
        this.create = new EventEmitter();
        this.update = new EventEmitter();
        this.selectionUpdate = new EventEmitter();
        this.transaction = new EventEmitter();
        this.focus = new EventEmitter();
        this.blur = new EventEmitter();
        this.destroy = new EventEmitter();
        // Editor input params
        this.content = null;
        this.injectCSS = true;
        this.autofocus = true;
        this.editable = true;
        this.editorProps = {};
        this.parseOptions = {};
        this.enableInputRules = true;
        this.enablePasteRules = true;
        this.destroy$ = new Subject();
        eventService.setElement(element.nativeElement);
    }
    get editor() {
        return this.tiptap ? this.tiptap : null;
    }
    ngAfterViewInit() {
        return __awaiter(this, void 0, void 0, function* () {
            // On the serve you don't need an editor
            if (!isPlatformBrowser(this.platformId))
                return;
            if (!this.editorComponent) {
                throw new Error('You have to pass the tip-editor-body as a child of the tip-editor. Otherwise you cannot see anything');
            }
            // Attach the editor to the editor element
            this.tiptap = yield this.tiptapService.getEditor(this.editorComponent.editorElement, this.buildEditorOptions());
            // Emit the event which indicates that the tiptap editor was created
            this.created.emit(this.tiptap);
            // Pass the editor the the editorBody component
            this.editorComponent.setEditor(this.tiptap);
            // Check if the header component was passed and if not disable it
            this.headerComponent && this.headerComponent.setEditor(this.tiptap);
            this.registerEvents();
        });
    }
    ngOnDestroy() {
        this.tiptap && this.tiptap.destroy();
        this.destroy$.next(true);
        this.destroy.complete();
    }
    registerEvents() {
        if (!this.tiptap)
            return;
        this.ngZone.runOutsideAngular(() => {
            this.pipeTo(fromEditorEvent(this.tiptap, 'update').pipe(map(({ editor }) => editor.getJSON())), this.jsonChange);
            this.pipeTo(fromEditorEvent(this.tiptap, 'update').pipe(map(({ editor }) => editor.getHTML())), this.htmlChange);
            this.pipeTo(fromEditorEvent(this.tiptap, 'beforeCreate'), this.beforeCreate);
            this.pipeTo(fromEditorEvent(this.tiptap, 'create'), this.create);
            this.pipeTo(fromEditorEvent(this.tiptap, 'update'), this.update);
            this.pipeTo(fromEditorEvent(this.tiptap, 'selectionUpdate'), this.selectionUpdate);
            this.pipeTo(fromEditorEvent(this.tiptap, 'transaction'), this.transaction);
            this.pipeTo(fromEditorEvent(this.tiptap, 'focus'), this.focus);
            this.pipeTo(fromEditorEvent(this.tiptap, 'blur'), this.blur);
            this.pipeTo(fromEditorEvent(this.tiptap, 'destroy'), this.destroy);
        });
    }
    buildEditorOptions() {
        return {
            content: this.content,
            autofocus: this.autofocus,
            injectCSS: this.injectCSS,
            editable: this.editable,
            editorProps: this.editorProps,
            parseOptions: this.parseOptions,
            enableInputRules: this.enableInputRules,
            enablePasteRules: this.enablePasteRules,
        };
    }
    pipeTo(observable, eventEmitter) {
        observable
            .pipe(takeUntil(this.destroy$))
            .subscribe(e => eventEmitter.next(e));
    }
}
EditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-editor',
                template: `
    <ng-content select="tip-editor-header"></ng-content>
    <ng-content select="tip-editor-body"></ng-content>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [TiptapEventService],
                styles: [""]
            },] }
];
EditorComponent.ctorParameters = () => [
    { type: TiptapService },
    { type: NgZone },
    { type: ElementRef },
    { type: undefined, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] },
    { type: DialogService },
    { type: TiptapEventService }
];
EditorComponent.propDecorators = {
    jsonChange: [{ type: Output }],
    htmlChange: [{ type: Output }],
    created: [{ type: Output }],
    beforeCreate: [{ type: Output }],
    create: [{ type: Output }],
    update: [{ type: Output }],
    selectionUpdate: [{ type: Output }],
    transaction: [{ type: Output }],
    focus: [{ type: Output }],
    blur: [{ type: Output }],
    destroy: [{ type: Output }],
    content: [{ type: Input }],
    injectCSS: [{ type: Input }],
    autofocus: [{ type: Input }],
    editable: [{ type: Input }],
    editorProps: [{ type: Input }],
    parseOptions: [{ type: Input }],
    enableInputRules: [{ type: Input }],
    enablePasteRules: [{ type: Input }],
    editorComponent: [{ type: ContentChild, args: [EditorBodyComponent,] }],
    headerComponent: [{ type: ContentChild, args: [EditorHeaderComponent,] }]
};

class SideBySideComponent {
    constructor() {
        this.destroy$ = new Subject();
    }
    ngAfterViewInit() {
        this.editor.jsonChange
            .pipe(takeUntil(this.destroy$))
            .subscribe((content) => {
            this.preview.renderOutput(content);
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.complete();
    }
}
SideBySideComponent.decorators = [
    { type: Component, args: [{
                selector: 'tip-side-by-side',
                changeDetection: ChangeDetectionStrategy.OnPush,
                template: `
    <ng-content select="tip-editor"></ng-content>
    <div class="preview-wrapper">
      <div class="preview-heading v-center h-center">
        <h2 class="no-margin">Preview</h2>
      </div>
      <ng-content select="tip-editor-preview"></ng-content>
    </div>
  `,
                styles: [`
    :host-context {
      display: flex;
      width: 100%;
    }

    .preview-heading {
      border-bottom: solid 1px var(--tip-border-color);
      padding: var(--tip-header-padding);
      height: var(--tip-header-height);
      box-sizing: border-box;
    }

    .preview-wrapper {
      border: solid 1px var(--tip-border-color);
      border-left: none;
      width: 50%;
    }

    ::ng-deep tip-side-by-side > tip-editor {
      width: 50%;
    }
  `]
            },] }
];
SideBySideComponent.propDecorators = {
    editor: [{ type: ContentChild, args: [EditorComponent,] }],
    preview: [{ type: ContentChild, args: [EditorPreviewComponent,] }]
};

class AutofocusDirective {
    constructor(element, ngZone) {
        this.element = element;
        this.ngZone = ngZone;
        this.enable = true;
    }
    ngAfterViewInit() {
        if (typeof this.enable === 'string' || this.enable) {
            this.ngZone.runOutsideAngular(() => setTimeout(() => this.element.nativeElement.focus()));
        }
    }
}
AutofocusDirective.decorators = [
    { type: Directive, args: [{
                selector: '[tipAutofocus]'
            },] }
];
AutofocusDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: NgZone }
];
AutofocusDirective.propDecorators = {
    enable: [{ type: Input, args: ['tipAutofocus',] }]
};

class NgxTipTapEditorModule {
}
NgxTipTapEditorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    // Editor
                    EditorComponent,
                    EditorBodyComponent,
                    EditorHeaderComponent,
                    // Preview
                    EditorPreviewComponent,
                    SideBySideComponent,
                    // Control alignment
                    ControlBreakLineComponent,
                    ControlHorizontalDividerComponent,
                    ControlSpacerComponent,
                    ControlVerticalDividerComponent,
                    // Controls
                    BoldControlComponent,
                    BulletListControlComponent,
                    CodeBlockControlComponent,
                    CodeControlComponent,
                    FormatControlComponent,
                    HorizontalRuleControlComponent,
                    ItalicControlComponent,
                    NumberListControlComponent,
                    StrikeControlComponent,
                    TextAlignControlComponent,
                    UnderlineControlComponent,
                    LinkControlComponent,
                    // Common
                    OptionComponent,
                    SelectComponent,
                    DialogComponent,
                    // Private
                    LinkSelectComponent,
                    AutofocusDirective,
                    LinkPreviewComponent,
                    PopoverComponent
                ],
                imports: [
                    CommonModule,
                    BrowserAnimationsModule,
                    BrowserModule,
                    FormsModule
                ],
                exports: [
                    // Editor
                    EditorComponent,
                    EditorBodyComponent,
                    EditorHeaderComponent,
                    // Preview
                    EditorPreviewComponent,
                    SideBySideComponent,
                    // Control alignment
                    ControlBreakLineComponent,
                    ControlHorizontalDividerComponent,
                    ControlSpacerComponent,
                    ControlVerticalDividerComponent,
                    // Controls
                    BoldControlComponent,
                    BulletListControlComponent,
                    CodeBlockControlComponent,
                    CodeControlComponent,
                    FormatControlComponent,
                    HorizontalRuleControlComponent,
                    ItalicControlComponent,
                    NumberListControlComponent,
                    StrikeControlComponent,
                    TextAlignControlComponent,
                    UnderlineControlComponent,
                    LinkControlComponent,
                    // Common
                    OptionComponent,
                    SelectComponent,
                ],
                providers: []
            },] }
];

/*
 * Public API Surface of ngx-tiptap-editor
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BaseControl, BoldControlComponent, BulletListControlComponent, CodeBlockControlComponent, CodeControlComponent, ControlBreakLineComponent, ControlHorizontalDividerComponent, ControlSpacerComponent, ControlVerticalDividerComponent, EditorBodyComponent, EditorComponent, EditorHeaderComponent, EditorPreviewComponent, FormatControlComponent, HorizontalRuleControlComponent, ItalicControlComponent, LinkControlComponent, NgxTipTapEditorModule, NumberListControlComponent, OptionComponent, SelectComponent, SideBySideComponent, StrikeControlComponent, TIP_TAP_EXTENSIONS, TextAlignControlComponent, UnderlineControlComponent, extensionLoaderFactory, ExtendedBaseControl as ɵb, ButtonBaseControl as ɵc, SelectBaseControl as ɵd, TiptapEventService as ɵe, TiptapService as ɵf, DialogService as ɵg, FadeInAnimation as ɵh, ExpandHeight as ɵi, DialogComponent as ɵj, DIALOG_DATA as ɵk, DialogRef as ɵl, DialogBaseClass as ɵm, PopOverPopUpAnimation as ɵn, OverlayPopUpAnimation as ɵo, LinkSelectComponent as ɵp, AutofocusDirective as ɵq, LinkPreviewComponent as ɵr, PopoverComponent as ɵs };
//# sourceMappingURL=ngx-tiptap-editor.js.map
