import { ComponentRef, InjectionToken, NgZone, OnDestroy, OnInit } from '@angular/core';
import { DialogService } from '../../services/dialog.service';
export declare const DIALOG_DATA: InjectionToken<DialogData<any>>;
export interface OverlayData<D> {
    data?: D;
    autoClose: boolean;
    maxWidth: string;
    width: string;
    backdropColor: string;
}
export interface DialogData<D> extends OverlayData<D> {
    type: 'dialog';
    position: 'top' | 'center';
}
export interface PopoverData<D> extends OverlayData<D> {
    type: 'popover';
    position: {
        x: number;
        y: number;
    };
}
export interface ResultData<D> {
    data: ResultData<D>['status'] extends 'canceled' ? null : D;
    status: 'success' | 'canceled';
}
export declare class DialogRef<RESULT, CONFIG_DATA, COMPONENT> {
    private _componentInstance;
    private dialogService;
    private dialogComponentRef;
    private config;
    private subject$;
    result$: import("rxjs").Observable<ResultData<RESULT>>;
    private status;
    constructor(_componentInstance: COMPONENT, dialogService: DialogService, dialogComponentRef: {
        component?: ComponentRef<DialogBaseClass>;
    }, config: DialogData<CONFIG_DATA> | PopoverData<CONFIG_DATA>);
    get componentInstance(): COMPONENT;
    get dialogConfig(): Omit<DialogData<CONFIG_DATA>, 'data'> | Omit<PopoverData<CONFIG_DATA>, 'data'>;
    private get dialogComponent();
    setStatus(status: ResultData<RESULT>['status']): void;
    closeDialog(data: RESULT): void;
}
export declare abstract class DialogBaseClass implements OnInit, OnDestroy {
    protected abstract ngZone: NgZone;
    protected abstract document: Document;
    protected abstract dialogRef: DialogRef<any, any, any>;
    private destroy$;
    ngOnInit(): void;
    ngOnDestroy(): void;
    closeDialog(): void;
}
