import { AfterViewInit, ElementRef, OnDestroy, OnInit, QueryList } from '@angular/core';
import type { Editor } from '@tiptap/core';
import { Subject } from 'rxjs';
import { TiptapEventService } from '../../../services/tiptap-event.service';
import { OptionComponent, SelectComponent } from '../../select/select.component';
export interface BaseControl {
    onEditorReady?(editor: Editor): void;
}
export declare abstract class BaseControl {
    private _editor;
    get editor(): Editor | null;
    setEditor(editor: Editor): void;
}
export declare abstract class ExtendedBaseControl extends BaseControl implements OnDestroy {
    protected destroy$: Subject<boolean>;
    ngOnDestroy(): void;
    protected isEditable(): boolean;
}
export declare abstract class ButtonBaseControl extends ExtendedBaseControl implements OnInit, OnDestroy, AfterViewInit {
    protected button: ElementRef<HTMLElement> | undefined;
    protected abstract eventService: TiptapEventService;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    setEditor(editor: Editor): void;
    protected abstract isActive(...args: any): boolean | Promise<boolean>;
    protected abstract can(...args: any): boolean | Promise<boolean>;
    private updateButton;
}
export declare abstract class SelectBaseControl extends ExtendedBaseControl implements OnInit, OnDestroy, AfterViewInit {
    protected abstract eventService: TiptapEventService;
    protected abstract canStyleParams: any[];
    protected select: SelectComponent;
    protected options: QueryList<OptionComponent>;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    setEditor(editor: Editor): void;
    protected abstract canStyle(...args: any[]): boolean | Promise<boolean>;
    protected abstract currentActive(): any | Promise<any>;
    private updateSelectValue;
    private updateDisabledValue;
}
